# transfer.sh

[![Publish to PyPI](https://github.com/MayankFawkes/transfer.sh/actions/workflows/pypi-publish.yml/badge.svg)](https://github.com/MayankFawkes/transfer.sh/actions/workflows/pypi-publish.yml)
![ver](https://img.shields.io/pypi/pyversions/transfer.sh)
![lang](https://img.shields.io/github/languages/top/mayankfawkes/transfer.sh)
![status](https://img.shields.io/pypi/status/transfer.sh)
![ver](https://img.shields.io/pypi/v/transfer.sh)
[![Downloads](https://pepy.tech/badge/transfer-sh/week)](https://pepy.tech/project/transfer-sh)

# Guide
One command installation

## Python module
run commands on terminal.

```
$ pip install -U transfer.sh
```

Have multipls versions of python?

```
$ python3.x -m pip install -U transfer.sh
```

## CLI
Command line help

### Upload file
```
$ transfer upload file.txt
```
### Remove file
```
$ transfer remove <uploaded file hash>
```
